[GHC] #5536: IO performance regression in 7.2 vs 7.0

GHC cvs-ghc at haskell.org
Mon Oct 10 13:22:50 CEST 2011


#5536: IO performance regression in 7.2 vs 7.0
---------------------------------+------------------------------------------
    Reporter:  simonmar          |        Owner:  batterseapower
        Type:  bug               |       Status:  new           
    Priority:  high              |    Milestone:  7.4.1         
   Component:  libraries/base    |      Version:  7.2.1         
    Keywords:                    |     Testcase:                
   Blockedby:                    |   Difficulty:                
          Os:  Unknown/Multiple  |     Blocking:                
Architecture:  Unknown/Multiple  |      Failure:  None/Unknown  
---------------------------------+------------------------------------------

Comment(by simonmar):

 After this commit:

 commit ea4bb083c6222e7c774fdb554f24f17a53ae350d
 {{{
 Author: Simon Peyton Jones <simonpj at microsoft.com>
 Date:   Wed Jul 27 08:39:14 2011 +0100

     Eliminate a thunk in the inner loop of 'unpack'

     This makes quite a difference to allocation in some
     programs.
 }}}

 The performance of `cat` improved to 5.81s (19% slower than 7.0), and the
 binary cat improved to 4.24s (27% slower than 7.0).  This is a lot better,
 but I hope there are more improvements to be had.  This is still a pretty
 big penalty.

-- 
Ticket URL: <http://hackage.haskell.org/trac/ghc/ticket/5536#comment:2>
GHC <http://www.haskell.org/ghc/>
The Glasgow Haskell Compiler



More information about the Glasgow-haskell-bugs mailing list